@@ -6,8 +6,6 @@ from wechatarticles import ArticlesAPI
 from wechatarticles import tools
 
 if __name__ == '__main__':
-    username = "username"
-    password = "password"
     official_cookie = "official_cookie"
     token = "token"
     appmsg_token = "appmsg_token"
@@ -21,12 +19,6 @@ if __name__ == '__main__':
                        appmsg_token=appmsg_token,
                        wechat_cookie=wechat_cookie)
 
-    # 输入账号密码，自动登录公众号，手动输入appmsg_token和wechat_cookie
-    test = ArticlesAPI(username=username,
-                       password=password,
-                       appmsg_token=appmsg_token,
-                       wechat_cookie=wechat_cookie)
-
     # 手动输入official_cookie和token, 自动获取appmsg_token和wechat_cookie
     test = ArticlesAPI(official_cookie=official_cookie,
                        token=token,
